# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.1]

- Handle additional case for related primary key field.

## [0.1.0]

- Change the hints API from `prefetch.Required` to `hints.Virtual`.

## [0.0.2]

- Fix documentation link on PyPI.

## [0.0.1]

- First release.
